@@ -1,44 +1,56 @@
-#' Wrapper for plotting large-sized data using shiny and plotly
+#' Wrapper for plotting large-sized data using \code{shinyHugePlot}
 #'
 #' @description
-#' This S3 class function is a wrapper to plot the large-sized data.
-#' It employs an R6 \code{shiny_downsampler} instance to obtain data samples
-#' using a specified aggregation method that is defined in the instance.
-#' The figure will be updated interactively according to the x-range
-#' that user select manually in the shiny app.
-#' @param obj Numeric vector, nanotime vector, numeric matrix, data.frame,
-#' or plotly object.
-#' If a numeric vector is given, it is used as the y values of the figure.
-#' the x values are calculated by \code{seq_along(obj)}.
-#' If you use \code{y} argument together, this argument is interpreted as
-#' the x values of the figure.
-#' If a nanotime vector is given, it is used as the x values of the figure.
-#' You must also give \code{y} argument, which will be used as the y values.
-#' Regarding \code{nanotime}, see the \code{nanotime} package.
-#' If a numeric matrix is given, the first and second column values are used
-#' as the x and y values. (The matrix must have more than 2 columns.)
-#' If a data.frame is given, \code{x} and \code{y} columns are used as the
-#' x and y values. If the class of the \code{x} column is \code{nanotime},
-#' the date type will be applied to the x axis.
-#' The data.frame must have columns named x and y.
-#' If a plotly object is given, it will be displayed.
+#' This is a S3 class function to easily plot large-sized data using
+#' \code{downsampler} object including \code{plotly} and
+#' \code{shiny} application.
+#' Using data that is given as a first argument,
+#' \code{shiny} application will be constructed and (by default,) executed.
+#' As the first argument, many classes are applicable,
+#' ranging from a numeric vector representing y values
+#' to a \code{downsampler} object containing
+#' original data, layout of the figure and
+#' options for aggregating the original data.
+#' @param obj Numeric/\code{nanotime}/\code{POSIXt} vector,
+#' numeric matrix, data.frame, single character string,
+#' \code{plotly} object, or \code{downsampler} object.
+#' If a numeric vector is given, it will be used as y values of the figure
+#' of the \code{shiny} application
+#' (the x values are calculated by \code{seq_along(obj)}).
+#' It will be interpreted as the x values if you use \code{y} argument together.
+#' If a \code{nanotime} (see \code{nanotime} package) vector is given,
+#' it will be used as the x values (\code{y} argument is mandatory).
+#' If a numeric matrix is given, which must have more than 2 columns,
+#' the first and second column values will be used as the x and y values.
+#' If a data frame is given,
+#' which must have columns named \code{x} and \code{y},
+#' these columns will be used as the x and y values.
+#' If a single character string is given, it will be used as a file path
+#' to obtain a data frame
+#' (data frame will be loaded using \code{data.table::fread}).
+#' If a \code{plotly} object is given, the data and layout of it will be used
+#' for constructing the figure of the \code{shiny} application.
+#' If a \code{downsampler} object is given, the data, layout, and
+#' down-sampling options for aggregating original data of it will be used for
+#' constructing \code{shiny} application.
 #' @param y Numeric vector, optional.
-#' The y values of the figure.
-#' It is required if the \code{obj} argument is used as x values of the figure.
+#' y values of the figure of \code{shiny} application,
+#' which is required if the \code{obj} argument is used as the x values.
 #' @param tz Timezone, optional.
-#' It is used to convert the nanotime to the time displayed in the figure.
-#' It is used if the class of the \code{obj} argument is nanotime.
+#' It is used to convert the \code{nanotime} to the time displayed in the figure.
 #' By default, \code{Sys.timezone()}.
 #' @param n_out Integer, optional.
 #' Number of samples get by the down-sampling. By default, 1000.
-#' @param aggregator R6 class for the aggregation, optional.
-#' Select an aggregation function. The list of the functions are obtained
-#' using \code{list_aggregators}.
+#' @param aggregator Instance of R6 classes for aggregating data, optional.
+#' The classes can be listed using \code{list_aggregators}.
 #' By default, \code{min_max_aggregator$new()}.
+#' @param fread_options Named list, optional.
+#' Arguments passed to \code{data.table::fread},
+#' which is used if a single character string is given as the \code{obj}.
 #' @param downsampler_options Named list, optional.
-#' Arguments passed to \code{shiny_downsampler$new}, other than
-#' \code{aggregator} and \code{n_shown_samples}.
-#' To set these arguments, use \code{aggregator} and \code{n_out} arguments.
+#' Arguments passed to \code{downsampler$new}.
+#' Note that use \code{aggregator} and \code{n_out} arguments
+#' if you want to set these arguments.
 #' @param plotly_options Named list, optional.
 #' Arguments passed to \code{plotly::plot_ly}.
 #' @param plotly_layout_options Named list, optional.
@@ -49,11 +61,11 @@
 #' Arguments passed to \code{plotlyOutput}.
 #' By default, \code{100\%} and \code{600px}.
 #' @param run_shiny Boolean, optional.
-#' whether a generated shiny app will be run immediately.
+#' whether a generated \code{shiny} application will be launched.
 #' By default, \code{TRUE}.
 #' @param use_light_build Boolean, optional.
-#' Whether a light version of the plotly data builder
-#' (\code{plotly_data_light}) implemented in this package is used.
+#' Whether \code{shinyHugePlot::plotly_build_light} will be used.
+#' (if \code{FALSE}, \code{plotly::plotly_build} will be used)
 #' By default, \code{TRUE}.
 #' @param ... Not used.
 #' @importFrom htmltools div br
@@ -154,6 +166,37 @@ shiny_hugeplot.default <- function(
 }
 
 
+#' @rdname shiny_hugeplot
+#' @export
+shiny_hugeplot.character <- function(
+    obj = NULL,
+    n_out = 1000L,
+    aggregator = min_max_aggregator$new(),
+    run_shiny = TRUE,
+    use_light_build = TRUE,
+    fread_options = list(),
+    downsampler_options = list(),
+    plotly_options = list(type = "scatter", mode = "lines"),
+    plotly_layout_options = list(),
+    shiny_options = list(),
+    width = "100%", height = "600px",
+    ...
+) {
+
+  args <- c(as.list(environment()), list(...))
+  assertthat::assert_that(inherits(fread_options, "list"))
+
+  args$obj <- do.call(data.table::fread, c(args$obj, fread_options))
+
+  # proceed to shiny_hugeplot.default
+  app <- do.call(shiny_hugeplot, args)
+  if (run_shiny) {
+    invisible()
+  } else{
+    return(app)
+  }
+}
+
 #' @rdname shiny_hugeplot
 #' @export
 shiny_hugeplot.matrix <- function(
