@@ -7,37 +7,76 @@ d <- tibble::tibble(
   y_fct = cut(y, breaks = c(-Inf, seq(5, 30, 5), Inf))
 )
 
-test_that("Check regarding the abstract_aggregator", {
-  abs_agg <- abstract_aggregator$new(interleave_gaps = TRUE)
-  expect_is(abs_agg, c("abstract_aggregator","R6"))
+d_sep <- d[c(1, 50:1e4, 3e4:1e5, (2e5+3e4):(8e5), 9e5:1e6),]
 
-  d_agg <- abs_agg$aggregate(d$x, d$y, n_out = 100)
+test_that("Check regarding the base aggregator", {
+  bs_agg <- aggregator$new(interleave_gaps = TRUE)
+  expect_is(bs_agg, c("aggregator","R6"))
+})
+
+
+test_that("Check regarding the null", {
+  null_agg <- null_aggregator$new(interleave_gaps = TRUE)
+  expect_is(null_agg, c("aggregator","R6"))
+
+  d_agg <- null_agg$aggregate(d$x[1:100], d$y[1:100], n_out = 100)
   expect_equal(d_agg, list(x = d$x[1:100], y = d$y[1:100]))
 
-  expect_error(abs_agg$aggregate(d$x[1:100], d$y, n_out = 100))
+  expect_error(null_agg$aggregate(d$x[1:100], d$y, n_out = 100))
 
-  abs_agg_int <- abstract_aggregator$new(
+  null_agg_int <- aggregator$new(
     accepted_datatype = c("integer", "factor")
-    )
+  )
 
-  expect_error(abs_agg_int$aggregate(d$x, d$y, n_out = 100))
+  expect_error(null_agg_int$aggregate(d$x, d$y, n_out = 100))
 
-  d_replace_NA <- abs_agg$aggregate(
-    d$x[c(1, 100:500)], d$y[c(1, 100:500)], n_out = 100
-    )
+  d_replace_NA_begin <- null_agg$aggregate(
+    d$x[c(1, 2, 100:500)], d$y[c(1,2, 100:500)], n_out = -1
+  )
 
   expect_equal(
-    d_replace_NA,
+    d_replace_NA_begin,
     list(
-      x = c(d$x[1], NA, d$x[101:198]),
-      y = c(d$y[1], NA, d$y[101:198])
+      x = c(d$x[1], NA, d$x[100:500]),
+      y = c(d$y[1], NA, d$y[100:500])
     )
   )
 
 
-  d_insert_NA <- abs_agg$aggregate(
-    d$x[c(1, 51:100)], d$y[c(1, 51:100)], n_out = 100
+  null_agg_end <- null_aggregator$new(
+    interleave_gaps = TRUE, NA_position = "end"
     )
+  d_replace_NA_end <- null_agg_end$aggregate(
+    d$x[c(1, 2, 100:500)], d$y[c(1,2, 100:500)], n_out = -1
+  )
+
+  expect_equal(
+    d_replace_NA_end,
+    list(
+      x = c(d$x[c(1,2)], NA, d$x[101:500]),
+      y = c(d$y[c(1,2)], NA, d$y[101:500])
+    )
+  )
+
+
+  null_agg_both <- null_aggregator$new(
+    interleave_gaps = TRUE, NA_position = "both"
+  )
+  d_replace_NA_both <- null_agg_both$aggregate(
+    d$x[c(1, 2, 100:500)], d$y[c(1,2, 100:500)], n_out = -1
+  )
+
+  expect_equal(
+    d_replace_NA_both,
+    list(
+      x = c(d$x[c(1)], NA, NA, d$x[101:500]),
+      y = c(d$y[c(1)], NA, NA, d$y[101:500])
+    )
+  )
+
+  d_insert_NA <- null_agg$aggregate(
+    d$x[c(1, 51:100)], d$y[c(1, 51:100)]
+  )
 
   expect_equal(
     d_insert_NA,
@@ -50,7 +89,6 @@ test_that("Check regarding the abstract_aggregator", {
 })
 
 
-
 test_that("Check nth-point aggregator", {
   nth_agg <- nth_pnt_aggregator$new()
   d_agg <- nth_agg$aggregate(d$x[1:1e4], d$y[1:1e4], n_out = 100)
@@ -70,6 +108,11 @@ test_that("Check min-max-ovlp aggregator", {
   expect_equal(length(d_agg), 2)
   expect_equal(length(d_agg$x), 100)
   expect_equal(d$y[d_agg$x + 1], d_agg$y)
+
+  minmax_ovlp_agg_na <- min_max_ovlp_aggregator$new(interleave_gaps = TRUE)
+  d_sep_agg <- minmax_ovlp_agg_na$aggregate(d_sep$x, d_sep$y, n_out = 100)
+  sum(is.na(d_sep_agg$x))
+
 })
 
 
@@ -80,6 +123,11 @@ test_that("Check min-max aggregator", {
   expect_equal(length(d_agg), 2)
   expect_equal(length(d_agg$x), 100)
   expect_equal(d$y[d_agg$x + 1], d_agg$y)
+
+  minmax_agg_na <- min_max_aggregator$new(interleave_gaps = TRUE)
+  d_sep_agg <- minmax_agg_na$aggregate(d_sep$x, d_sep$y, n_out = 100)
+  sum(is.na(d_sep_agg$x))
+
 })
 
 
@@ -110,7 +158,7 @@ test_that("Check LTTB aggregator using factor y", {
 })
 
 
-test_that("Efficient LTTB aggregator", {
+test_that("Check Efficient LTTB aggregator", {
   eLTTB_agg <- eLTTB_aggregator$new()
   d_agg <- eLTTB_agg$aggregate(d$x, d$y, n_out = 100)
 
@@ -118,3 +166,28 @@ test_that("Efficient LTTB aggregator", {
   expect_equal(length(d_agg$x), 100)
 })
 
+test_that("Check range stat aggregator", {
+  rs_agg <- range_stat_aggregator$new()
+  d_agg <- rs_agg$aggregate(d$x, d$y, n_out = 100)
+
+  expect_equal(length(d_agg), 4)
+  expect_equal(length(d_agg$x), 100)
+
+  d_agg_pr <- do.call(rs_agg$as_plotly_range, d_agg)
+  expect_equal(length(d_agg_pr), 1)
+  expect_equal(length(d_agg_pr[[1]]), 6)
+
+  rs_agg_na <- range_stat_aggregator$new(interleave_gaps = TRUE)
+  d_sep_agg <- rs_agg_na$aggregate(d_sep$x, d_sep$y, n_out = 100)
+
+  prng <- do.call(rs_agg_na$as_plotly_range, d_sep_agg)
+
+  expect_equal(length(prng[[1]]), 6)
+
+  drng <- purrr::map(prng, ~rs_agg_na$as_range(.x) %>% tibble::as_tibble()) %>%
+    bind_rows()
+
+  expect_equal(sum(!is.na(d_sep_agg$x)), nrow(drng))
+
+  })
+
